@@ -10,17 +10,17 @@ import requests
 from sentry.plugins.bases.notify import NotificationPlugin
 import sentry_wechat
 from django import forms
+from django.utils.translation import ugettext_lazy as _
 
 
 class WechatForm(forms.Form):
-    key = forms.CharField(
-        max_length=255,
-        help_text='WeChat robot key'
-    )
+    urls = forms.CharField(
+        label=_('Wechat robot url'),
+        widget=forms.Textarea(attrs={
+            'class': 'span6', 'placeholder': 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=xxx-xxx-xxx-xxx-xxx'}),
+        help_text=_('Enter wechat robot url.'))
 
 
-WeChat_API = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={key}"
-
 class WechatPlugin(NotificationPlugin):
     """
     Sentry plugin to send error counts to WeChat.
@@ -40,6 +40,12 @@ class WechatPlugin(NotificationPlugin):
     conf_key = 'wechat'
     project_conf_form = WechatForm
 
+    def get_webhook_urls(self, project):
+        url = self.get_option('urls', project)
+        if not url:
+            return ''
+        return url
+
     def is_configured(self, project):
         """
         Check if plugin is configured.
@@ -59,23 +65,25 @@ class WechatPlugin(NotificationPlugin):
         if group.is_ignored():
             return
 
-        key = self.get_option('key', group.project)
-        send_url = WeChat_API.format(key=key)
-        title = u'【%s】的项目异常' % event.project.slug
+        send_url = self.get_webhook_urls(group.project)
+        title = '【{}】发生错误，请尽快查看处理!' .format(event.project.slug)
+        url = "{}events/{}/".format(group.get_absolute_url(), event.event_id),
 
         data = {
-            "msgtype": "markdown",
-            "markdown": {
-                "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n [详细信息]({url})".format(
-                    title=title,
-                    message=event.title or event.message,
-                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
-                )
+            "msgtype": "news",
+            "news": {
+                "articles": [
+                    {
+                        "title": title,
+                        "description": event.title or event.message,
+                        "url": url,
+                        "picurl": "http://pic1.zhimg.com/v2-c41cd2b3b6c58245908ad89f7ddc55e7_b.jpg"
+                    }
+                ]
             }
         }
         requests.post(
             url=send_url,
             headers={"Content-Type": "application/json"},
-            data=json.dumps(data).encode("utf-8")
-        )
\ No newline at end of file
+            data=json.dumps(data)
+        )
